Plugins/VcsPlugins/vcsPySvn/SvnBlameDialog.py

changeset 4126
c28d0cf3b639
parent 4021
195a471c327b
child 4278
ccd1e13cb9bd
diff -r 056d98a54dd4 -r c28d0cf3b639 Plugins/VcsPlugins/vcsPySvn/SvnBlameDialog.py
--- a/Plugins/VcsPlugins/vcsPySvn/SvnBlameDialog.py	Sun Feb 22 12:16:32 2015 +0100
+++ b/Plugins/VcsPlugins/vcsPySvn/SvnBlameDialog.py	Sun Feb 22 19:21:55 2015 +0100
@@ -58,10 +58,11 @@
         
     def start(self, fn):
         """
         Public slot to start the svn status command.
         
-        @param fn filename to show the log for (string)
+        @param fn filename to show the blame for (string)
         """
+        self.blameList.clear()
         self.errorGroup.hide()
         self.activateWindow()
         
@@ -58,10 +58,11 @@
     def start(self, fn):
         """
-        Public slot to start the svn status command.
+        Public slot to start the svn blame command.
         

eric ide

mercurial